==> sns3_7.zip: sns3_7/plugin/core.pl <==
################################################################################
#
# ɸץ饰
#
################################################################################
#===============================================================================
# եɽ
#===============================================================================
sub login_form {
	my $buf = "<form action=\"diary.cgi\" method=\"POST\">\n";
	if($main::LOGIN==0){
		$buf .= "<input type=\"password\" name=\"Password\" size=\"10\">";
		$buf .= "<input type=\"hidden\"   name=\"do_login\" value=\"1\">";
		$buf .= "<input type=\"submit\"   name=\"do_login\" value=\"\">\n";
	} else {
		$buf .= "<input type=\"submit\" name=\"do_logout\" value=\"\">\n";
	}
	$buf .= "</form>\n";
	return $buf;
}

#===============================================================================
# եɽ
#===============================================================================
sub search_form {
	my $buf = "<form action=\"diary.cgi\" method=\"POST\">\n".
	          "<input type=\"text\" name=\"Search\" value=\"".&Util::escapeHTML($cgi->param("Search"))."\">".
	          "<input type=\"submit\" value=\"\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ڡԤΥ󥫤ɽ
#===============================================================================
sub page_anchor {
	my $rows = $cgi->param("r");
	$rows = 0 if $rows eq "";
	my $once = $config->{once};
	my $buf = "";
	if($rows+$once <= $#list){
		$buf .= "<a href=\"diary.cgi?".$param."r=".($rows+$once)."\">&lt;$once</a> ";
	}
	if($rows>0){
		$buf .= "<a href=\"diary.cgi?".$param."r=".($rows-$once)."\">$once&gt;</a>";
	}
	return $buf;
}

#===============================================================================
# ܤɽ
#===============================================================================
sub calendar {
	my $label = shift;
	my $html = "<form action=\"diary.cgi\" method=\"GET\">$label ".
	           "<select name=\"Date\">\n";
	
	my @list = glob("$main::DATA_DIR/*.dat");
	@list = sort {$b cmp $a} @list;
	
	my $selyear = $cgi->param("Year");
	my $selmon  = $cgi->param("Month");
	
	for(my $i=0;$i<=$#list;$i++){
		$list[$i] =~ /\/([0-9]{4})([0-9]{2})([0-9]{2})\.dat$/;
		my $year = int($1);
		for(my $month=12;$month>=1;$month--){
			my $flag = 0;
			for(my $j=0;$j<=$#list;$j++){
				$list[$j] =~ /\/([0-9]{4})([0-9]{2})([0-9]{2})\.dat$/;
				my $list_year  = int($1);
				my $list_month = int($2);
				if($list_year==$year && $list_month==$month){
					$flag = 1;
				}
			}
			
			if($flag){
				$html .= "<option value=\"$year-$month\"";
				if($year==$selyear && $month==$selmon){
					$html .= " selected";
				}
				$html .= ">$year-$month</option>\n";
			}
		}
		while($list[$i] =~ /\/$year[0-9]{2}[0-9]{2}\.dat$/){ $i++; }
	}
	
	return $html."</select><input type=\"submit\" value=\"ɽ\"></form>";
}
#===============================================================================
# ǿΥȤɽ
#===============================================================================
sub recent_comment {
	my $num = shift;
	if($num eq ""){ $num = 3; }
	
	my @TMP;
	foreach my $file (glob("$main::DATA_DIR/*.cmt")){
		open(DATA,$file);
		$file =~ /\/([0-9]+?)\.cmt/;
		my $year  = substr($1,0,4);
		my $month = substr($1,4,2);
		my $day   = substr($1,6,2);
		
		while(my $LINE=<DATA>){
			chomp($LINE);
			push(@TMP,$LINE.",".$year.",".$month.",".$day);
		}
		close(DATA);
	}
	
	@TMP = sort {
		my @value_a = split(/,/,$a);
		my @value_b = split(/,/,$b);
		
		if(@value_a[2]>@value_b[2]){
			return -1;
		} elsif(@value_a[2]<@value_b[2]){
			return 1;
		} else {
			return 0;
		}
	}(@TMP);
	
	my @list;
	my $ret   = "";
	my $count = 0;
	foreach(@TMP){
		if($count==$num){ last; }
		my ($name,$comment,$date,$year,$mon,$day) = split(/,/,$_);
		
		$ret = $ret."<b>".($count+1).".</b>".
		            "<a href=\"diary.cgi?Year=$year&Month=$mon".
		            "&Day=$day\" title=\"".&Util::escapeHTML($comment)."\">".
		            &Util::escapeHTML($name).
		            " (".&Util::format_short_date($date).")</a> ";
		$count++;
	}
	
	return $ret;
}
#===============================================================================
# źեեؤΥ󥯤
#===============================================================================
sub attach_file {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		return "<a href=\"diary.cgi?download=".&Util::url_encode($attach)."\">".&Util::escapeHTML($filename)."</a>";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# źդեϤĤ
#===============================================================================
sub attach_image {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		return "<img src=\"diary.cgi?download=".&Util::url_encode($attach)."\">";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# źդƥȥեѥƥȤȤƽϤ
#===============================================================================
sub attach_text {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		open(DATA,"$main::ATTACH_DIR/$attach");
		my $text = Unicode::Japanese->new(join("",<DATA>),'auto');
		close(DATA);
		return "<pre>".&Util::escapeHTML($text->conv('euc'))."</pre>";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# դȤ˥θФưɽ
#===============================================================================
sub section_list {
	my $max = shift;
	if($max eq ""){
		$max = 30;
	}
	my $buf = "";
	my @list = $sns->load_diary($max);
	foreach my $diary (@list){
		$buf .= sprintf("<b><a href=\"diary.cgi?Date=%s\">%04d/%02d/%02d</a></b>",
		                $diary->date,$diary->year,$diary->month,$diary->day);
		my @sections = $diary->parse();
		$buf .= "<ul>\n";
		foreach my $section (@sections){
			$buf .= "<li>".$section->{TITLE}."</li>\n";
		}
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

1;

==> sns3_10.zip: sns3_10/plugin/core.pl <==
################################################################################
#
# ɸץ饰
#
################################################################################
#===============================================================================
# եɽ
#===============================================================================
sub login_form {
	my $buf = "<form action=\"diary.cgi\" method=\"POST\">\n";
	if($main::LOGIN==0){
		$buf .= "<input type=\"password\" name=\"Password\" size=\"10\">";
		$buf .= "<input type=\"hidden\"   name=\"do_login\" value=\"1\">";
		$buf .= "<input type=\"submit\"   name=\"do_login\" value=\"$SNS::Lang::LOGIN\">\n";
	} else {
		$buf .= "<input type=\"submit\" name=\"do_logout\" value=\"$SNS::Lang::LOGOUT\">\n";
	}
	$buf .= "</form>\n";
	return $buf;
}

#===============================================================================
# եɽ
#===============================================================================
sub search_form {
	my $buf = "<form action=\"diary.cgi\" method=\"POST\">\n".
	          "<input type=\"text\" name=\"Search\" value=\"".&Util::escapeHTML($cgi->param("Search"))."\">".
	          "<input type=\"submit\" value=\"$SNS::Lang::SEARCH\">\n".
	          "</form>\n";
	
	return $buf;
}

#===============================================================================
# ڡԤΥ󥫤ɽ
#===============================================================================
sub page_anchor {
	my $rows = $cgi->param("r");
	$rows = 0 if $rows eq "";
	my $once = $config->{once};
	my $buf = "";
	if($rows+$once <= $#list){
		$buf .= "<a href=\"diary.cgi?".$param."r=".($rows+$once)."\">&lt;".sprintf($SNS::Lang::PREV, $once)."</a> ";
	}
	if($rows>0){
		$buf .= "<a href=\"diary.cgi?".$param."r=".($rows-$once)."\">". sprintf($SNS::Lang::NEXT, $once)."&gt;</a>";
	}
	return $buf;
}

#===============================================================================
# ܤɽ
#===============================================================================
sub calendar {
	my $label = shift;
	my $html = "<form action=\"diary.cgi\" method=\"GET\">$label ".
	           "<select name=\"Date\">\n";
	
	my @list = glob("$main::DATA_DIR/*.dat");
	@list = sort {$b cmp $a} @list;
	
	my $selyear = $cgi->param("Year");
	my $selmon  = $cgi->param("Month");
	
	for(my $i=0;$i<=$#list;$i++){
		$list[$i] =~ /\/([0-9]{4})([0-9]{2})([0-9]{2})\.dat$/;
		my $year = int($1);
		for(my $month=12;$month>=1;$month--){
			my $flag = 0;
			for(my $j=0;$j<=$#list;$j++){
				$list[$j] =~ /\/([0-9]{4})([0-9]{2})([0-9]{2})\.dat$/;
				my $list_year  = int($1);
				my $list_month = int($2);
				if($list_year==$year && $list_month==$month){
					$flag = 1;
				}
			}
			
			if($flag){
				$html .= "<option value=\"$year-$month\"";
				if($year==$selyear && $month==$selmon){
					$html .= " selected";
				}
				$html .= ">$year-$month</option>\n";
			}
		}
		while($list[$i] =~ /\/$year[0-9]{2}[0-9]{2}\.dat$/){ $i++; }
	}
	
	return $html."</select><input type=\"submit\" value=\"$SNS::Lang::DISPLAY\"></form>";
}
#===============================================================================
# ǿΥȤɽ
#===============================================================================
sub recent_comment {
	my $num = shift;
	if($num eq ""){ $num = 3; }
	
	my @TMP;
	foreach my $file (glob("$main::DATA_DIR/*.cmt")){
		open(DATA,$file);
		$file =~ /\/([0-9]+?)\.cmt/;
		my $year  = substr($1,0,4);
		my $month = substr($1,4,2);
		my $day   = substr($1,6,2);
		
		while(my $LINE=<DATA>){
			chomp($LINE);
			push(@TMP,$LINE.",".$year.",".$month.",".$day);
		}
		close(DATA);
	}
	
	@TMP = sort {
		my @value_a = split(/,/,$a);
		my @value_b = split(/,/,$b);
		
		if(@value_a[2]>@value_b[2]){
			return -1;
		} elsif(@value_a[2]<@value_b[2]){
			return 1;
		} else {
			return 0;
		}
	}(@TMP);
	
	my @list;
	my $ret   = "";
	my $count = 0;
	foreach(@TMP){
		if($count==$num){ last; }
		my ($name,$comment,$date,$year,$mon,$day) = split(/,/,$_);
		
		$ret = $ret."<b>".($count+1).".</b>".
		            "<a href=\"diary.cgi?Year=$year&Month=$mon".
		            "&Day=$day\" title=\"".&Util::escapeHTML($comment)."\">".
		            &Util::escapeHTML($name).
		            " (".&Util::format_short_date($date).")</a> ";
		$count++;
	}
	
	return $ret;
}
#===============================================================================
# źեեؤΥ󥯤
#===============================================================================
sub attach_file {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		return "<a href=\"diary.cgi?download=".&Util::url_encode($attach)."\">".&Util::escapeHTML($filename)."</a>";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# źդեϤĤ
#===============================================================================
sub attach_image {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		return "<img src=\"diary.cgi?download=".&Util::url_encode($attach)."\">";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# źդƥȥեѥƥȤȤƽϤ
#===============================================================================
sub attach_text {
	my $filename = shift;
	my $attach   = sprintf("%04d%02d%02d.%s",$diary->year,$diary->month,$diary->day,&Util::url_encode($filename));
	
	if(-e "$main::ATTACH_DIR/$attach"){
		open(DATA,"$main::ATTACH_DIR/$attach");
		my $text = Unicode::Japanese->new(join("",<DATA>),'auto');
		close(DATA);
		return "<pre>".&Util::escapeHTML($text->conv('euc'))."</pre>";
	} else {
		return "<font class=\"alert\">ե뤬¸ߤޤ</font>";
	}
}

#===============================================================================
# դȤ˥θФưɽ
#===============================================================================
sub section_list {
	my $max = shift;
	if($max eq ""){
		$max = 30;
	}
	my $buf = "";
	my @list = $sns->load_diary($max);
	foreach my $diary (@list){
		$buf .= sprintf("<b><a href=\"diary.cgi?Date=%s\">%04d/%02d/%02d</a></b>",
		                $diary->date,$diary->year,$diary->month,$diary->day);
		my @sections = $diary->parse();
		$buf .= "<ul>\n";
		foreach my $section (@sections){
			$buf .= "<li>".$section->{TITLE}."</li>\n";
		}
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

1;
